var express = require('express');
var path = require('path');
var favicon = require('serve-favicon');
var logger = require('morgan');
var cookieParser = require('cookie-parser');
var bodyParser = require('body-parser');

var routes = require('./routes/index');
var user = require('./routes/user');
var msg_group = require('./routes/msg_group');
var msg_p2p = require('./routes/msg_p2p');
var msg_system = require('./routes/msg_system');
var msg_statistic = require('./routes/msg_statistic');

var commons = require('./include/commons');
var config = require(commons.CONFIG_FILE);

var app = express();

var startDate = new Date();
console.log('==============================================');
console.log('');
console.log('Push Server started on ' + startDate.toLocaleString());
console.log('Version: ' + config.version);
console.log('');
console.log('==============================================');

// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'jade');

// uncomment after placing your favicon in /public
//app.use(favicon(__dirname + '/public/favicon.ico'));
app.use(logger('dev'));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, 'public')));

app.use('/', routes);
app.use('/user', user);
app.use('/group', msg_group);
app.use('/p2p', msg_p2p);
app.use('/system', msg_system);
app.use('/statistic', msg_statistic);

// catch 404 and forward to error handler
app.use(function(req, res, next) {
  var err = new Error('Not Found');
  err.status = 404;
  next(err);
});

// error handlers

// development error handler
// will print stacktrace
if (app.get('env') === 'development') {
  app.use(function(err, req, res, next) {
    res.status(err.status || 500);
    res.render('error', {
      message: err.message,
      error: err
    });
  });
}

// production error handler
// no stacktraces leaked to user
app.use(function(err, req, res, next) {
  res.status(err.status || 500);
  res.render('error', {
    message: err.message,
    error: {}
  });
});

process.on('uncaughtException', function (err) {
  console.log(err);
  console.log(err.stack);
});

module.exports = app;
